@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from pagseguro.validators import Email, PhoneArea, PhoneNumber, BrState
+from pagseguro.validators import Email, PhoneArea, PhoneNumber, BrState, NoDoubleSpace
 from voluptuous import Schema, Required, All, Length, Range, Optional, Match, \
     Any
 
@@ -8,13 +8,12 @@ item_schema = Schema({
     Required('description'): All(unicode, Length(min=1, max=100)),
     Required('amount'): All(float, Range(min=0.01, max=9999999)),
     Required('quantity'): All(int, Range(min=1, max=999)),
-    'shipping_cost': All(float, Range(min=0.01, max=9999999)),
     Optional('weight'): All(int, Range(max=30000)),
 })
 
 #: .. todo:: Validar born_date e CPF
 client_schema = Schema({
-    'name': unicode,
+    'name': All(NoDoubleSpace(), Length(max=50)),
     'email': All(Email(), Length(max=60)),
     'phone_area_code': All(PhoneArea(), Length(min=2, max=2)),
     'phone_number': All(PhoneNumber(), Length(min=7, max=9)),
